# Scrapetsy
Package to get product detail sold on www.etsy.com.

## HOW IT WORKS?
This package will scrape detail product from www.etsy.com using search page url as input

It will use eksternal package:
selenium, requests, random, json, os and csv

It is also need geckodriver.exe to run selenium, it can be downlowded here https://github.com/mozilla/geckodriver/releases 

Its output could be extracted CSV file or JSON file that is ready to use for any web or mobile application.